[pal-cvs 2558] [290] regenerated dbflute component

Back to archive index

svnno****@sourc***** svnno****@sourc*****
2007年 7月 19日 (木) 02:55:51 JST


Revision: 290
          http://svn.sourceforge.jp/cgi-bin/viewcvs.cgi?root=pal&view=rev&rev=290
Author:   takeharu
Date:     2007-07-19 02:55:50 +0900 (Thu, 19 Jul 2007)

Log Message:
-----------
regenerated dbflute component

Modified Paths:
--------------
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesBhv.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesDescriptionBhv.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDao.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDescriptionDao.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategories.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategoriesDescription.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDbm.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDescriptionDbm.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesCB.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesDescriptionCB.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesCQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesDescriptionCQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesCQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesDescriptionCQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesCIQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesDescriptionCIQ.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesDescriptionNss.java
    pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesNss.java


-------------- next part --------------
Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesBhv.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesBhv.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesBhv.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -11,6 +11,8 @@
 import jp.sf.pal.pompei.allcommon.cbean.PagingResultBean;
 import jp.sf.pal.pompei.allcommon.dbmeta.DBMeta;
   
+import jp.sf.pal.pompei.exbhv.*;
+  
 import jp.sf.pal.pompei.exdao.*;
 import jp.sf.pal.pompei.exentity.*;
 import jp.sf.pal.pompei.bsentity.dbmeta.*;
@@ -32,13 +34,13 @@
  *     
  * 
  * [refferer-property]
- *     
+ *     categoriesDescriptionList
  * 
  * [sequence]
  *     
  * 
  * [identity]
- *     
+ *     categoriesId
  * 
  * [update-date]
  *     
@@ -456,10 +458,156 @@
     //                                                                        Load Referer
     //                                                                        ============
   
+    // /* * * * * * * * * * * * * * * * * * * * * * *
+    //   RefererTable    = [CATEGORIES_DESCRIPTION]
+    //   RefererProperty = [categoriesDescriptionList]
+    // * * * * * * * * */
+    
+    /**
+     * Load referer of categoriesDescriptionList.
+     * <pre>
+     *   You can load referer.
+     * 
+     *   ex) {Client Example}
+     *     final CategoriesCB cb = new CategoriesCB();
+     *     cb.query().setXxx_Equal("xxx");
+     *     final List&lt;Categories&gt; categoriesList = categoriesBhv.selectList(cb);
+     *     categoriesBhv.loadCategoriesDescriptionList(categoriesList);
+     * 
+     *   *About internal policy, the value of primary key(and others too) is treated as CaseInsensitive.
+     * </pre>
+     * 
+     * @param categoriesList Entity list of categories. (NotNull)
+     */
+    public void loadCategoriesDescriptionList(java.util.List<Categories> categoriesList) {
+        final ConditionBeanSetupper<CategoriesDescriptionCB> conditionBeanSetupper = new ConditionBeanSetupper<CategoriesDescriptionCB>() {
+            public void setup(CategoriesDescriptionCB cb) {
+            }
+        };
+        loadCategoriesDescriptionList(categoriesList, conditionBeanSetupper);
+    }
+
+    /**
+     * Load referer of categoriesDescriptionList.
+     * <pre>
+     *   You can load referer with your original condition.
+     * 
+     *   ex) {Client Example}: Referer conditions are 'Xxx' is not null and order-by 'Yyy' desc
+     *     /- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+     *     final CategoriesCB cb = new CategoriesCB();
+     *     cb.query().setXxx_Equal("xxx");
+     *     final List&lt;Categories&gt; categoriesList = categoriesBhv.selectList(cb);
+     *     final ConditionBeanSetupper&lt;CategoriesDescriptionCB&gt; conditionBeanSetupper = new ConditionBeanSetupper&lt;CategoriesDescriptionCB&gt;() {
+     *         public void setup(CategoriesDescriptionCB cb) {
+     *             cb.query().setXxx_IsNotNull();
+     *             cb.query().addOrderBy_Yyy_Desc();
+     *         }
+     *     };
+     *     categoriesBhv.loadCategoriesDescriptionList(categoriesList, conditionBeanSetupper);
+     *     - - - - - - - - - -/
+     * 
+     *   The condition-bean that the setupper provides have settings before you touch it. It is as follows:
+     *     /- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+     *     cb.query().setCategoriesId_InScope(pkList);
+     *     cb.query().addOrderBy_CategoriesId_Asc();
+     *     - - - - - - - - - -/
+     * 
+     *   *About internal policy, the value of primary key(and others too) is treated as CaseInsensitive.
+     * </pre>
+     * 
+     * @param categoriesList Entity list of categories. (NotNull)
+     * @param conditionBeanSetupper Referer condition setupper instance for registering referer condition. (NotNull)
+     */
+    public void loadCategoriesDescriptionList(java.util.List<Categories> categoriesList, ConditionBeanSetupper<CategoriesDescriptionCB> conditionBeanSetupper) {
+        assertObjectNotNull("categoriesList<Categories>", categoriesList);
+        assertObjectNotNull("conditionBeanSetupper<CategoriesDescriptionCB>", conditionBeanSetupper);
+        if (categoriesList.isEmpty()) {
+            return;
+        }
+        loadCategoriesDescriptionList(categoriesList, new LoadRefererOption<CategoriesDescriptionCB, CategoriesDescription>(conditionBeanSetupper));
+    }
+
+    /**
+     * Load referer of categoriesDescriptionList.
+     * <pre>
+     *   You can load referer with your original condition.
+     * 
+     *   ex) {Client Example}: Referer conditions are 'Xxx' is not null and order-by 'Yyy' desc
+     *     /- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+     *     final CategoriesCB cb = new CategoriesCB();
+     *     cb.query().setXxx_Equal("xxx");
+     *     final List&lt;Categories&gt; categoriesList = categoriesBhv.selectList(cb);
+     *     final ConditionBeanSetupper&lt;CategoriesDescriptionCB&gt; cbSetupper = new ConditionBeanSetupper&lt;CategoriesDescriptionCB&gt;() {
+     *         public void setup(CategoriesDescriptionCB cb) {
+     *             cb.query().setXxx_IsNotNull();
+     *             cb.query().addOrderBy_Yyy_Desc();
+     *         }
+     *     };
+     *     categoriesBhv.loadCategoriesDescriptionList(categoriesList, new LoadRefererOption<CategoriesDescriptionCB, CategoriesDescription>(cbSetupper));
+     *     - - - - - - - - - -/
+     * 
+     *   The condition-bean that the setupper provides have settings before you touch it. It is as follows:
+     *     /- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+     *     cb.query().setCategoriesId_InScope(pkList);
+     *     cb.query().addOrderBy_CategoriesId_Asc();
+     *     - - - - - - - - - -/
+     * 
+     *   *About internal policy, the value of primary key(and others too) is treated as CaseInsensitive.
+     * </pre>
+     * 
+     * @param categoriesList Entity list of categories. (NotNull)
+     * @param loadRefererOption Load-referer option. (NotNull)
+     */
+    public void loadCategoriesDescriptionList(java.util.List<Categories> categoriesList, LoadRefererOption<CategoriesDescriptionCB, CategoriesDescription> loadRefererOption) {
+        assertObjectNotNull("categoriesList<Categories>", categoriesList);
+        assertObjectNotNull("loadRefererOption<CategoriesDescription, CategoriesDescriptionCB>", loadRefererOption);
+        if (categoriesList.isEmpty()) {
+            return;
+        }
+
+        final java.util.Map<java.math.BigDecimal, Categories> pkMyEntityMap = new java.util.LinkedHashMap<java.math.BigDecimal, Categories>();
+        final java.util.List<java.math.BigDecimal> pkList = new java.util.ArrayList<java.math.BigDecimal>();
+        for (Categories categories : categoriesList) {
+            pkList.add(categories.getCategoriesId());
+            pkMyEntityMap.put((java.math.BigDecimal)toLowerCaseIfString(categories.getCategoriesId()), categories);
+        }
+        final CategoriesDescriptionBhv refererBhv = getDaoSelector().getBehavior(CategoriesDescriptionBhv.class);
+        final CategoriesDescriptionCB cb = loadRefererOption.getReffererConditionBean() != null ? loadRefererOption.getReffererConditionBean() : refererBhv.newMyConditionBean();
+        cb.query().setCategoriesId_InScope(pkList);
+        loadRefererOption.delegateKeyConditionExchangingFirstWhereClauseForLastOne(cb);
+        if (!loadRefererOption.isStopOrderByKey()) {
+            cb.query().addOrderBy_CategoriesId_Asc();
+            cb.getSqlComponentOfOrderByClause().exchangeFirstOrderByElementForLastOne();
+        }
+        loadRefererOption.delegateConditionBeanSettingUp(cb);
+        final java.util.List<CategoriesDescription> reffererList = refererBhv.selectList(cb);
+        loadRefererOption.delegateEntitySettingUp(reffererList);
+
+        final java.util.Map<java.math.BigDecimal, java.util.List<CategoriesDescription>> pkReffererListMap = new java.util.LinkedHashMap<java.math.BigDecimal, java.util.List<CategoriesDescription>>();
+        for (CategoriesDescription reffererEntity : reffererList) {
+            if (!pkReffererListMap.containsKey(toLowerCaseIfString(reffererEntity.getCategoriesId()))) {
+                pkReffererListMap.put((java.math.BigDecimal)toLowerCaseIfString(reffererEntity.getCategoriesId()), new java.util.ArrayList<CategoriesDescription>());
+            }
+            (pkReffererListMap.get(toLowerCaseIfString(reffererEntity.getCategoriesId()))).add(reffererEntity);
+
+            // for Reverse Reference.
+            final Categories myEntity = pkMyEntityMap.get(toLowerCaseIfString(reffererEntity.getCategoriesId()));
+            reffererEntity.setCategories(myEntity);
+        }
+
+        for (Categories categories : categoriesList) {
+            if (pkReffererListMap.containsKey(toLowerCaseIfString(categories.getCategoriesId()))) {
+                categories.setCategoriesDescriptionList((java.util.List<CategoriesDescription>)pkReffererListMap.get(toLowerCaseIfString(categories.getCategoriesId())));
+            } else {
+                categories.setCategoriesDescriptionList(new java.util.ArrayList<CategoriesDescription>());
+            }
+        }
+    }
+      
     // ===================================================================================
     //                                                                    Pull Out Foreign
     //                                                                    ================
-
+  
     // ===================================================================================
     //                                                                 Basic Entity Update
     //                                                                 ===================
@@ -680,6 +828,30 @@
     // ===================================================================================
     //                                                                      Various Insert
     //                                                                      ==============
+      
+    /* (non-javadoc) 
+     * Copy-insert.
+     * 
+     * @param primaryKey Primary-keys. (NotNull)
+     * @return Inserted count.
+     * @exception jp.sf.pal.pompei.allcommon.exception.RecordHasAlreadyBeenDeletedException
+     */
+    public int copyInsertByPKValueAfterSelect(java.math.BigDecimal categoriesId) {
+        Categories entity = new Categories();
+        entity.setCategoriesId(categoriesId);
+        final CategoriesCB cb = newMyConditionBean();
+        cb.acceptPrimaryKeyMapString(getDBMeta().extractPrimaryKeyMapString(entity));
+        final Categories currentEntity = selectEntityWithDeletedCheck(cb);
+        return delegateInsert(currentEntity);
+    }
+    
+    /**
+     * Filter 'copy-insert' entity.
+     * 
+     * @param categories Entity. (NotNull)
+     */
+    protected void filterCopyInsertEntity(Categories categories) {
+    }
   
     // ===================================================================================
     //                                                                          CBSetupper

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesDescriptionBhv.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesDescriptionBhv.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsbhv/BsCategoriesDescriptionBhv.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -29,7 +29,7 @@
  *     CATEGORIES_ID, LANGUAGE_ID, CATEGORIES_NAME
  * 
  * [foreign-property]
- *     
+ *     categories
  * 
  * [refferer-property]
  *     
@@ -456,6 +456,26 @@
     //                                                                    Pull Out Foreign
     //                                                                    ================
 
+    /**
+     * Pull out the list of foreign table 'Categories'.
+     * 
+     * @param categoriesDescriptionList The list of categoriesDescription. (NotNull)
+     * @return The list of foreign table. (NotNull)
+     */
+    public java.util.List<Categories> pulloutCategories(java.util.List<CategoriesDescription> categoriesDescriptionList) {
+        assertObjectNotNull("categoriesDescriptionList", categoriesDescriptionList);
+        final java.util.Set<Categories> foreignSet = new java.util.LinkedHashSet<Categories>();
+        for (java.util.Iterator ite = categoriesDescriptionList.iterator(); ite.hasNext(); ) {
+            final CategoriesDescription categoriesDescription = (CategoriesDescription)ite.next();
+            final Categories foreignEntity = categoriesDescription.getCategories();
+            if (foreignEntity == null || foreignSet.contains(foreignEntity)) {
+                continue;
+            }
+            foreignSet.add(foreignEntity);
+        }
+        return new java.util.ArrayList<Categories>(foreignSet);
+    }
+
     // ===================================================================================
     //                                                                 Basic Entity Update
     //                                                                 ===================

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDao.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDao.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDao.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -17,13 +17,13 @@
  *     
  * 
  * [refferer-property]
- *     
+ *     categoriesDescriptionList
  * 
  * [sequence]
  *     
  * 
  * [identity]
- *     
+ *     categoriesId
  * 
  * [update-date]
  *     

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDescriptionDao.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDescriptionDao.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsdao/BsCategoriesDescriptionDao.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -14,7 +14,7 @@
  *     CATEGORIES_ID, LANGUAGE_ID, CATEGORIES_NAME
  * 
  * [foreign-property]
- *     
+ *     categories
  * 
  * [refferer-property]
  *     

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategories.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategories.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategories.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -19,13 +19,13 @@
  *     
  * 
  * [refferer-property]
- *     
+ *     categoriesDescriptionList
  * 
  * [sequence]
  *     
  * 
  * [identity]
- *     
+ *     categoriesId
  * 
  * [update-date]
  *     
@@ -45,6 +45,9 @@
     /** TABLE-Annotation for S2Dao */
     public static final String TABLE = "CATEGORIES";
 
+    
+    /** ID-Annotation */
+    public static final String categoriesId_ID = "identity";
 
     // ===================================================================================
     //                                                                           Attribute
@@ -53,7 +56,7 @@
     protected EntityModifiedProperties _modifiedProperties = newEntityModifiedProperties();
 
   
-    /** The value of categoriesId. ColumnDefinition -- PK : INTEGER : NotNull*/
+    /** The value of categoriesId. ColumnDefinition -- PK : INC : INTEGER : NotNull : Default=[AUTOINCREMENT: start 1 increment 1]*/
     protected java.math.BigDecimal _categoriesId;
     
     /** The value of categoriesImage. ColumnDefinition -- VARCHAR(64)*/
@@ -127,12 +130,12 @@
     //                                                                            Accessor
     //                                                                            ========
 
-    /** Column-Annotation for S2Dao. ColumnDefinition -- PK : INTEGER : NotNull*/
+    /** Column-Annotation for S2Dao. ColumnDefinition -- PK : INC : INTEGER : NotNull : Default=[AUTOINCREMENT: start 1 increment 1]*/
     public static final String categoriesId_COLUMN = "CATEGORIES_ID";
 
     /**
      * Get the value of categoriesId. <br />
-     * {PK : INTEGER : NotNull}
+     * {PK : INC : INTEGER : NotNull : Default=[AUTOINCREMENT: start 1 increment 1]}
      * 
      * @return The value of categoriesId. (Nullable)
      */
@@ -142,7 +145,7 @@
 
     /**
      * Set the value of categoriesId. <br />
-     * {PK : INTEGER : NotNull}
+     * {PK : INC : INTEGER : NotNull : Default=[AUTOINCREMENT: start 1 increment 1]}
      * 
      * @param categoriesId The value of categoriesId. (Nullable)
      */
@@ -294,6 +297,34 @@
     //                                                                      Refferer Table
     //                                                                      ==============
 
+  
+    // /* * * * * * * * * * * * * * * * * * * * * * *
+    //   ReffererTable    = [CATEGORIES_DESCRIPTION]
+    //   ReffererProperty = [categoriesDescriptionList]
+    // * * * * * * * * */
+  
+    /** The list of refferer table. */
+    protected java.util.List<jp.sf.pal.pompei.exentity.CategoriesDescription> _childrenCategoriesDescriptionList;
+
+    /**
+     * Get the list of refferer table without lazyload.
+     * If it's not loaded yet, returns null.
+     * 
+     * @return The list of refferer table. (Nullable)
+     */
+    public java.util.List<jp.sf.pal.pompei.exentity.CategoriesDescription> getCategoriesDescriptionList() {
+        return _childrenCategoriesDescriptionList;
+    }
+
+    /**
+     * Set the list of refferer table.
+     * 
+     * @param value The list of refferer table. (Nullable)
+     */
+    public void setCategoriesDescriptionList(java.util.List<jp.sf.pal.pompei.exentity.CategoriesDescription> entity) {
+        this._childrenCategoriesDescriptionList = entity;
+    }
+  
     // ===================================================================================
     //                                                                              Accept
     //                                                                              ======

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategoriesDescription.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDbm.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDbm.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -20,13 +20,13 @@
  *     
  * 
  * [refferer-property]
- *     
+ *     categoriesDescriptionList
  * 
  * [sequence]
  *     
  * 
  * [identity]
- *     
+ *     categoriesId
  * 
  * [update-date]
  *     
@@ -109,6 +109,8 @@
     public static final String COLUMN_CAP_PROP_NAME_OF_LastModified = "LastModified";
 
 
+    /** Cap-prop-name of CategoriesDescriptionList. */
+    public static final String COLUMN_CAP_PROP_NAME_OF_CategoriesDescriptionList = "CategoriesDescriptionList";
 
     /** Uncap-prop-name of CategoriesId. */
     public static final String COLUMN_UNCAP_PROP_NAME_OF_CategoriesId = "categoriesId";
@@ -124,6 +126,8 @@
     public static final String COLUMN_UNCAP_PROP_NAME_OF_LastModified = "lastModified";
 
 
+    /** Uncap-prop-name of categoriesDescriptionList. */
+    public static final String COLUMN_UNCAP_PROP_NAME_OF_CategoriesDescriptionList = "categoriesDescriptionList";
 
     /** {db-name : cap-prop-name} map. */
     private static java.util.Map<String, String> _dbNameCapPropNameMap;
@@ -472,7 +476,7 @@
             throw new RuntimeException(e.getCause());
         }
     }
-
+  
     // ===================================================================================
     //                                                                       Determination
     //                                                                       =============

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDescriptionDbm.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDescriptionDbm.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDescriptionDbm.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -17,7 +17,7 @@
  *     CATEGORIES_ID, LANGUAGE_ID, CATEGORIES_NAME
  * 
  * [foreign-property]
- *     
+ *     categories
  * 
  * [refferer-property]
  *     
@@ -96,6 +96,8 @@
     /** Cap-prop-name of CategoriesName. */
     public static final String COLUMN_CAP_PROP_NAME_OF_CategoriesName = "CategoriesName";
 
+    /** Cap-prop-name of categories. */
+    public static final String COLUMN_CAP_PROP_NAME_OF_Categories = "Categories";
 
 
     /** Uncap-prop-name of CategoriesId. */
@@ -105,6 +107,8 @@
     /** Uncap-prop-name of CategoriesName. */
     public static final String COLUMN_UNCAP_PROP_NAME_OF_CategoriesName = "categoriesName";
 
+    /** Uncap-prop-name of categories. */
+    public static final String COLUMN_UNCAP_PROP_NAME_OF_Categories = "categories";
 
 
     /** {db-name : cap-prop-name} map. */
@@ -437,6 +441,15 @@
         }
     }
 
+    /**
+     * Get foreign dbmeta of Categories.
+     * 
+     * @return Foreign DBMeta. (NotNull)
+     */
+    public CategoriesDbm getForeignDBMeta_Categories() {
+        return CategoriesDbm.getInstance();
+    }
+
     // ===================================================================================
     //                                                                       Determination
     //                                                                       =============

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesCB.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesCB.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesCB.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -189,7 +189,7 @@
     // ===================================================================================
     //                                                                        Setup-Select
     //                                                                        ============
-    
+          
     // ===================================================================================
     //                                                                      Basic Override
     //                                                                      ==============

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesDescriptionCB.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesDescriptionCB.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/bs/BsCategoriesDescriptionCB.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -216,6 +216,50 @@
     // ===================================================================================
     //                                                                        Setup-Select
     //                                                                        ============
+  
+    // /* * * * * * * * * * * * * * * * * * * * * * *
+    //   ForeignTable    = [CATEGORIES]
+    //   ForeignProperty = [categories]
+    // * * * * * * * * */
+
+    /** Is select for categories? */
+    protected boolean _isSelectCategories;
+    /** Nest select setupper for categories. */
+    protected CategoriesNss _nssCategories;
+    /**
+     * Is select for categories? {For Internal}
+     * 
+     * @return Determination.
+     */
+    public boolean isSelectCategories() {
+        return _isSelectCategories;
+    }
+    /**
+     * Get nest select setupper for categories. {For Internal}
+     * 
+     * @return Nest select setupper. (NotNull)
+     */
+    public CategoriesNss getNssCategories() {
+        if (_nssCategories == null) {
+            _nssCategories = new CategoriesNss(null);// for Dummy
+        }
+        return _nssCategories;
+    }
+    /**
+     * Set up select for categories.
+     * If you invoke this, this entity is target of select.
+     * 
+     * @return Nest select setupper for categories. (NotNull)
+     */
+    public CategoriesNss setupSelect_Categories() {
+        query().queryCategories();// For setting outer join.
+        if (_nssCategories == null || !_nssCategories.hasConditionQuery()) {
+            _nssCategories = new CategoriesNss(query().queryCategories());
+        }
+        _isSelectCategories = true;
+        limitSelect_Off();
+        return _nssCategories;
+    }
     
     // ===================================================================================
     //                                                                      Basic Override

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesCQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesCQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesCQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -134,6 +134,40 @@
     public void setCategoriesId_NotInScope(java.util.List<java.math.BigDecimal> categoriesIdList) {
         registerCategoriesId(ConditionKey.CK_NOT_IN_SCOPE, categoriesIdList);
     }
+                          
+    /**
+     * Set the sub-query of CategoriesId_InScopeSubQuery_CategoriesDescriptionList using inScopeSubQuery.
+     * { in (select xxx.CATEGORIES_ID from CATEGORIES_DESCRIPTION where ...) }
+     * This method use from clause and where clause of the sub-query instance.
+     * this query keep the sub-query instance for query-value.
+     * After you invoke this, If you set query in the argument[subQuery], the query is ignored.
+     * 
+     * @param subQuery The sub-query of CategoriesId_InScopeSubQuery_CategoriesDescriptionList using inScopeSubQuery. (NotNull)
+     */
+    public void setCategoriesId_InScopeSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        assertObjectNotNull("subQuery", subQuery);
+        keepCategoriesId_InScopeSubQuery_CategoriesDescriptionList(subQuery);// for saving query-value.
+        registerInScopeSubQuery(subQuery, COL_CATEGORIES_ID, "CATEGORIES_ID", "categoriesId_InScopeSubQuery_CategoriesDescriptionList");
+    }
+
+    abstract public void keepCategoriesId_InScopeSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery);
+                                      
+    /**
+     * Set the sub-query of CategoriesId_ExistsSubQuery_CategoriesDescriptionList using existsSubQuery.
+     * { exists (select xxx.CATEGORIES_ID from CATEGORIES_DESCRIPTION where ...) }
+     * This method use from clause and where clause of the sub-query instance.
+     * this query keep the sub-query instance for query-value.
+     * After you invoke this, If you set query in the argument[subQuery], the query is ignored.
+     * 
+     * @param subQuery The sub-query of CategoriesId_ExistsSubQuery_CategoriesDescriptionList using existsSubQuery. (NotNull)
+     */
+    public void setCategoriesId_ExistsSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        assertObjectNotNull("subQuery", subQuery);
+        keepCategoriesId_ExistsSubQuery_CategoriesDescriptionList(subQuery);// for saving query-value.
+        registerExistsSubQuery(subQuery, COL_CATEGORIES_ID, "CATEGORIES_ID", "categoriesId_ExistsSubQuery_CategoriesDescriptionList");
+    }
+
+    abstract public void keepCategoriesId_ExistsSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery);
                                                 
     /**
      * Register condition of categoriesId.

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesDescriptionCQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesDescriptionCQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/AbstractBsCategoriesDescriptionCQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -134,8 +134,25 @@
     public void setCategoriesId_NotInScope(java.util.List<java.math.BigDecimal> categoriesIdList) {
         registerCategoriesId(ConditionKey.CK_NOT_IN_SCOPE, categoriesIdList);
     }
-                                                
+            
     /**
+     * Set the sub-query of CategoriesId_InScopeSubQuery_Categories using inScopeSubQuery.
+     * { in (select xxx.CATEGORIES_ID from CATEGORIES where ...) }
+     * This method use from clause and where clause of the sub-query instance.
+     * this query keep the sub-query instance for query-value.
+     * After you invoke this, If you set query in the argument[subQuery], the query is ignored.
+     * 
+     * @param subQuery The sub-query of CategoriesId_InScopeSubQuery_Categories using inScopeSubQuery. (NotNull)
+     */
+    public void setCategoriesId_InScopeSubQuery_Categories(CategoriesCQ subQuery) {
+        assertObjectNotNull("subQuery", subQuery);
+        keepCategoriesId_InScopeSubQuery_Categories(subQuery);// for saving query-value.
+        registerInScopeSubQuery(subQuery, COL_CATEGORIES_ID, "CATEGORIES_ID", "categoriesId_InScopeSubQuery_Categories");
+    }
+
+    abstract public void keepCategoriesId_InScopeSubQuery_Categories(CategoriesCQ subQuery);
+                                          
+    /**
      * Register condition of categoriesId.
      * 
      * @param key Condition key. (NotNull)

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesCQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesCQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesCQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -194,8 +194,40 @@
         return getCategoriesId();
     }
 
-                                                        
+                                  
+    /** The sub-query of CategoriesId_InScopeSubQuery_CategoriesDescriptionList using inScopeSubQuery. */
+    protected CategoriesDescriptionCQ _categoriesId_InScopeSubQuery_CategoriesDescriptionList;
+
     /**
+     * Get the sub-query of CategoriesId_InScopeSubQuery_CategoriesDescriptionList using inScopeSubQuery.
+     * 
+     * @return The sub-query of CategoriesId_InScopeSubQuery_CategoriesDescriptionList using inScopeSubQuery. (Nullable)
+     */
+    public CategoriesDescriptionCQ getCategoriesId_InScopeSubQuery_CategoriesDescriptionList() {
+        return _categoriesId_InScopeSubQuery_CategoriesDescriptionList;
+    }
+
+    public void keepCategoriesId_InScopeSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        _categoriesId_InScopeSubQuery_CategoriesDescriptionList = subQuery;
+    }
+                                                
+    /** The sub-query of CategoriesId_ExistsSubQuery_CategoriesDescriptionList using existsSubQuery. */
+    protected CategoriesDescriptionCQ _categoriesId_ExistsSubQuery_CategoriesDescriptionList;
+
+    /**
+     * Get the sub-query of CategoriesId_ExistsSubQuery_CategoriesDescriptionList using existsSubQuery.
+     * 
+     * @return The sub-query of CategoriesId_ExistsSubQuery_CategoriesDescriptionList using existsSubQuery. (Nullable)
+     */
+    public CategoriesDescriptionCQ getCategoriesId_ExistsSubQuery_CategoriesDescriptionList() {
+        return _categoriesId_ExistsSubQuery_CategoriesDescriptionList;
+    }
+
+    public void keepCategoriesId_ExistsSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        _categoriesId_ExistsSubQuery_CategoriesDescriptionList = subQuery;
+    }
+                                                
+    /**
      * Add order-by of categoriesId as ASC.
      * 
      * @return this. (NotNull)
@@ -429,12 +461,12 @@
     protected void reflectRelationOnUnionQuery(ConditionQuery baseQueryAsSuper, ConditionQuery unionQueryAsSuper) {
         final CategoriesCQ baseQuery = (CategoriesCQ)baseQueryAsSuper;
         final CategoriesCQ unionQuery = (CategoriesCQ)unionQueryAsSuper;
-    
+          
     }
 
     // ===================================================================================
     //                                                                       Foreign Query
     //                                                                       =============
   
-  
+        
 }

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesDescriptionCQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesDescriptionCQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/bs/BsCategoriesDescriptionCQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -140,8 +140,24 @@
         return getCategoriesId();
     }
 
-                                                        
+                    
+    /** The sub-query of CategoriesId_InScopeSubQuery_Categories using inScopeSubQuery. */
+    protected CategoriesCQ _categoriesId_InScopeSubQuery_Categories;
+
     /**
+     * Get the sub-query of CategoriesId_InScopeSubQuery_Categories using inScopeSubQuery.
+     * 
+     * @return The sub-query of CategoriesId_InScopeSubQuery_Categories using inScopeSubQuery. (Nullable)
+     */
+    public CategoriesCQ getCategoriesId_InScopeSubQuery_Categories() {
+        return _categoriesId_InScopeSubQuery_Categories;
+    }
+
+    public void keepCategoriesId_InScopeSubQuery_Categories(CategoriesCQ subQuery) {
+        _categoriesId_InScopeSubQuery_Categories = subQuery;
+    }
+                                          
+    /**
      * Add order-by of categoriesId as ASC.
      * 
      * @return this. (NotNull)
@@ -249,12 +265,81 @@
     protected void reflectRelationOnUnionQuery(ConditionQuery baseQueryAsSuper, ConditionQuery unionQueryAsSuper) {
         final CategoriesDescriptionCQ baseQuery = (CategoriesDescriptionCQ)baseQueryAsSuper;
         final CategoriesDescriptionCQ unionQuery = (CategoriesDescriptionCQ)unionQueryAsSuper;
+  
+        if (baseQuery.hasConditionQueryCategories()) {
+            unionQuery.queryCategories().reflectRelationOnUnionQuery(baseQuery.queryCategories(), unionQuery.queryCategories());
+        }
     
     }
 
     // ===================================================================================
     //                                                                       Foreign Query
     //                                                                       =============
+      
+    // /* * * * * * * * * * * * * * * * * * * * * * *
+    //   ForeignTable    = [CATEGORIES]
+    //   ForeignProperty = [categories]
+    // * * * * * * * * */
+
+    /**
+     * Query for categories.
+     * 
+     * @return Instance of CategoriesCQ as categories. (NotNull)
+     */
+    public CategoriesCQ queryCategories() {
+        return getConditionQueryCategories();
+    }
+
+    /** Condition-query for categories. */
+    protected CategoriesCQ _conditionQueryCategories;
+
+    /**
+     * Get condition-query for categories.
+     * 
+     * @return Instance of CategoriesCQ as categories. (NotNull)
+     */
+    public CategoriesCQ getConditionQueryCategories() {
+        if (_conditionQueryCategories == null) {
+            _conditionQueryCategories = newQueryCategories();
+            setupOuterJoin_Categories();
+        }
+        return _conditionQueryCategories;
+    }
+
+    /**
+     * Setup outer join for ${foreignPropertyName}.
+     */
+    protected void setupOuterJoin_Categories() {
+        final java.util.Map<String, String> joinOnMap = new java.util.LinkedHashMap<String, String>();
+        String key = null;
+        String value = null;
+    
+        key = getRealColumnName("CATEGORIES_ID");
+        value = getConditionQueryCategories().getRealColumnName("CATEGORIES_ID");
+        joinOnMap.put(key, value);
+    
+        final String joinTableName = "CATEGORIES";
+        final String aliasName = getConditionQueryCategories().getRealAliasName();
+        getSqlClause().registerOuterJoin(joinTableName, aliasName, joinOnMap);
+    }
+
+    /**
+     * New query for categories.
+     * 
+     * @return Query for categories. (NotNull)
+     */
+    protected CategoriesCQ newQueryCategories() {
+        return new CategoriesCQ(this, getSqlClause(), "Categories", getNextNestLevel());
+    }
+
+    /**
+     * Has condition query?
+     * 
+     * @return Determination.
+     */
+    public boolean hasConditionQueryCategories() {
+        return _conditionQueryCategories != null;
+    }
   
   
 }

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesCIQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesCIQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesCIQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -74,7 +74,16 @@
         return _myCQ.getCategoriesId();
     }
 
-                                                        
+                            
+    public void keepCategoriesId_InScopeSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        _myCQ.keepCategoriesId_InScopeSubQuery_CategoriesDescriptionList(subQuery);
+    }
+                                      
+    public void keepCategoriesId_ExistsSubQuery_CategoriesDescriptionList(CategoriesDescriptionCQ subQuery) {
+        throw new UnsupportedOperationException("ExistsSubQuery at inline() is unsupported! Sorry!");
+        // _myCQ.keepCategoriesId_ExistsSubQuery_CategoriesDescriptionList(subQuery);
+    }
+                                                      
     // /- - - - - - - - - - - - - - - - - - - - - - -
     //   Column = [CATEGORIES_IMAGE]
     // - - - - - - - - -/

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesDescriptionCIQ.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesDescriptionCIQ.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/cq/ciq/CategoriesDescriptionCIQ.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -74,7 +74,11 @@
         return _myCQ.getCategoriesId();
     }
 
-                                                        
+              
+    public void keepCategoriesId_InScopeSubQuery_Categories(CategoriesCQ subQuery) {
+        _myCQ.keepCategoriesId_InScopeSubQuery_Categories(subQuery);
+    }
+                                                
     // /- - - - - - - - - - - - - - - - - - - - - - -
     //   Column = [LANGUAGE_ID]
     // - - - - - - - - -/

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesDescriptionNss.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesDescriptionNss.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesDescriptionNss.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -52,6 +52,27 @@
     //                                                                             With...
     //                                                                             =======
 
+    /** Is select categories? */
+    protected boolean _isSelectCategories;
+
+    /**
+     * Is select categories?
+     * 
+     * @return Determination.
+     */
+    public boolean isSelectCategories() {
+        return _isSelectCategories;
+    }
+
+    /**
+     * Set up select with categories.
+     */
+    public void withCategories() {
+        assertConditionQuery();
+        _query.queryCategories();
+        _isSelectCategories = true;
+    }
+
     // ===================================================================================
     //                                                                              Helper
     //                                                                              ======

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesNss.java
===================================================================
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesNss.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/cbean/nss/CategoriesNss.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -51,7 +51,7 @@
     // ===================================================================================
     //                                                                             With...
     //                                                                             =======
-
+  
     // ===================================================================================
     //                                                                              Helper
     //                                                                              ======


pal-cvs メーリングリストの案内
Back to archive index
--- pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategoriesDescription.java	2007-07-18 17:55:01 UTC (rev 289)
+++ pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/BsCategoriesDescription.java	2007-07-18 17:55:50 UTC (rev 290)
@@ -16,7 +16,7 @@
  *     CATEGORIES_ID, LANGUAGE_ID, CATEGORIES_NAME
  * 
  * [foreign-property]
- *     
+ *     categories
  * 
  * [refferer-property]
  *     
@@ -53,7 +53,7 @@
     protected EntityModifiedProperties _modifiedProperties = newEntityModifiedProperties();
 
   
-    /** The value of categoriesId. ColumnDefinition -- PK : INTEGER : NotNull : Default=[0]*/
+    /** The value of categoriesId. ColumnDefinition -- PK : INTEGER : NotNull : Default=[0] : FK to CATEGORIES*/
     protected java.math.BigDecimal _categoriesId;
     
     /** The value of languageId. ColumnDefinition -- PK : INTEGER : NotNull : Default=[1]*/
@@ -118,12 +118,12 @@
     //                                                                            Accessor
     //                                                                            ========
 
     /** Column-Annotation for S2Dao. ColumnDefinition -- PK : INTEGER : NotNull : Default=[0]*/
     public static final String categoriesId_COLUMN = "CATEGORIES_ID";
 
     /**
      * Get the value of categoriesId. <br />
-     * {PK : INTEGER : NotNull : Default=[0]}
+     * {PK : INTEGER : NotNull : Default=[0] : FK to CATEGORIES}
      * 
      * @return The value of categoriesId. (Nullable)
      */
@@ -133,7 +133,7 @@
 
     /**
      * Set the value of categoriesId. <br />
-     * {PK : INTEGER : NotNull : Default=[0]}
+     * {PK : INTEGER : NotNull : Default=[0] : FK to CATEGORIES}
      * 
      * @param categoriesId The value of categoriesId. (Nullable)
      */
@@ -209,6 +209,48 @@
     //                                                                       Foreign Table
     //                                                                       =============
 
+    // /* * * * * * * * * * * * * * * * * * * * * * *
+    //   ForeignTable    = [CATEGORIES]
+    //   ForeignProperty = [categories]
+    // * * * * * * * * */
+
+    /** RELNO of foreign table for s2dao. */
+    public static final int categories_RELNO = 0;
+
+    /** RELKEYS of foreign table for s2dao. */
+    public static final String categories_RELKEYS = "CATEGORIES_ID:CATEGORIES_ID";
+
+    /** The entity of foreign table. */
+    protected jp.sf.pal.pompei.exentity.Categories _parentCategories;
+
+    /**
+     * Get the entity of foreign table without lazyload.
+     * 
+     * @return The entity of foreign table.
+     */
+    public jp.sf.pal.pompei.exentity.Categories getCategories() {
+        return _parentCategories;
+    }
+
+    /**
+     * Set the entity of foreign table.
+     * 
+     * @param v The entity of foreign table.
+     */
+    public void setCategories(jp.sf.pal.pompei.exentity.Categories entity) {
+        this._parentCategories = entity;
+    }
+
+    /**
+     * Has relation object of categories.
+     * 
+     * @return Determination.
+     */
+    public boolean hasRelationCategories() {
+        return _parentCategories != null && _parentCategories.hasPrimaryKeyValue();
+    }
+
+  
     // ===================================================================================
     //                                                                      Refferer Table
     //                                                                      ==============
@@ -118,12 +118,12 @@
     //                                                                            ========
 
-    /** Column-Annotation for S2Dao. ColumnDefinition -- PK : INTEGER : NotNull : Default=[0]*/
+    /** Column-Annotation for S2Dao. ColumnDefinition -- PK : INTEGER : NotNull : Default=[0] : FK to CATEGORIES*/
     public static final String categoriesId_COLUMN = "CATEGORIES_ID";
 

Modified: pompei/trunk/src/main/java/jp/sf/pal/pompei/bsentity/dbmeta/CategoriesDbm.java
===================================================================